@@ -1,6 +1,6 @@
 package Flux;
 {
-  $Flux::VERSION = '1.02';
+  $Flux::VERSION = '1.03';
 }
 
 # ABSTRACT: stream processing toolkit
@@ -18,26 +18,26 @@ Flux - stream processing toolkit
 
 =head1 VERSION
 
-version 1.02
+version 1.03
 
 =head1 SYNOPSIS
 
-use Flux::Simple qw( array_in array_out mapper );
+  use Flux::Simple qw( array_in array_out mapper );
 
-my $in = array_in([ 5, 6, 7 ]);
-$in = $in | mapper { shift() * 2 };
+  my $in = array_in([ 5, 6, 7 ]);
+  $in = $in | mapper { shift() * 2 };
 
-my @result;
-my $out = array_out(\@result);
-$out = mapper { shift() * 3 } | mapper { shift() . "x" } | $out;
+  my @result;
+  my $out = array_out(\@result);
+  $out = mapper { shift() * 3 } | mapper { shift() . "x" } | $out;
 
-$out->write($in->read);
-$out->write($in->read);
-say for @result;
+  $out->write($in->read);
+  $out->write($in->read);
+  say for @result;
 
-# Output:
-# 30x
-# 36x
+  # Output:
+  # 30x
+  # 36x
 
 =head1 DESCRIPTION
 
@@ -49,7 +49,7 @@ C<Flux::*> module namespace includes:
 
 =item *
 
-groundwork for interoperable input and output stream classes;
+groundwork for interoperable L<input|Flux::In> and L<output|Flux::Out> stream classes;
 
 =item *
 
@@ -57,7 +57,7 @@ various implementations of input and output streams and storages: in-memory, fil
 
 =item *
 
-tools for making these streams work together nicely: filters, data formatters, overloading syntax sugar, etc;
+tools for making these streams work together nicely: L<mappers|Flux::Mapper>, L<data formatters|Flux::Format>, overloading syntax sugar, etc;
 
 =item *
 
@@ -65,7 +65,7 @@ C<Flux::Catalog> module for the simple access to your collection of streams.
 
 =back
 
-Flux is a framework, but you can use lower-level parts of it without higher-level parts. For example, you can read and write files with C<Flux::File> without declaring it in the Flux catalog.
+Flux is a framework, but you can use lower-level parts of it without higher-level parts. For example, you can read and write files with L<Flux::File> without declaring it in the Flux catalog.
 
 =head1 INTERFACE STABILITY NOTICE
 
@@ -82,10 +82,10 @@ It should be stable. We used it in production for years. But remember that:
 =head1 SIMILAR MODULES
 
 L<Message::Passing> is similar to Flux.
-Unlike Flux, it's asynchronous (Flux can be made asynchronous by using L<Coro>, but its basic APIs are blocking).
-Unlike Flux, it doesn't support persistent data storing; Flux has fault-tolerance built in through explicit C<commit>.
 
-L<IO::Pipeline> syntax is similar to Flux filters.
+Unlike Flux, it's asynchronous (Flux can be made asynchronous by using L<Coro>, but its basic APIs are blocking).
+
+L<IO::Pipeline> syntax is similar to Flux mappers.
 
 I'm sure there're many others. Stream processing is reinvented often.
 
