@@ -1,9 +1,10 @@
 package Flux::In::Role::Easy;
 {
-  $Flux::In::Role::Easy::VERSION = '1.02';
+  $Flux::In::Role::Easy::VERSION = '1.03';
 }
 
-# ABSTRACT: role to implement input streams with only one read() method
+# ABSTRACT: simplified version of Flux::In role
+
 
 use Moo::Role;
 with 'Flux::In';
@@ -24,6 +25,7 @@ sub read_chunk {
 sub commit {
 }
 
+
 1;
 
 __END__
@@ -32,11 +34,29 @@ __END__
 
 =head1 NAME
 
-Flux::In::Role::Easy - role to implement input streams with only one read() method
+Flux::In::Role::Easy - simplified version of Flux::In role
 
 =head1 VERSION
 
-version 1.02
+version 1.03
+
+=head1 DESCRIPTION
+
+This role is an extension of L<Flux::In> role. It provides the sane C<read_chunk> implementation and the empty C<commit> implementation, so you only have to define C<read>.
+
+=head1 CONSUMER SYNOPSIS
+
+    use Moo;
+    with "Flux::In::Role::Easy";
+
+    my $i = 0;
+    sub read {
+        return $i++;
+    }
+
+=head1 SEE ALSO
+
+This role is a specialization of L<Flux::In>.
 
 =head1 AUTHOR
 
